Timeflux audio plugin
=====================

This plugin allows you to synthesis and play audio streams using Timeflux.

Installation
------------

First, make sure that `Timeflux <https://github.com/timeflux/timeflux>`__ is installed.

You can then install this plugin in the `timeflux` environment:

::

    $ conda activate timeflux
    $ pip install timeflux_audio
